@@ -1,9 +1,9 @@
 package Acme::Kensiro;
 use strict;
 use warnings;
-use base qw/Exporter/;
+use Exporter 'import';
 our @EXPORT = 'kensiro';
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub kensiro {
     my $src = shift;
